<template>
  <el-dialog
    width="60%"
    title="检测标准搜索"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="staff-dialog"
  >
    <el-row>
      <el-col :span="12">
        <ttable
          :table="table"
          @handleSelectionChange="handleSelectionChange"
          @currentChange="handleCurrentChange"
          :uploadInfo="uploadInfo"
          :prelang="prelang"
          :options="options"
          :bottomOffset="200"
          :ajaxFun="ajaxFun"
          ref="moTestStandardTable"
        >
          <template #toolbar></template>
        </ttable>
      </el-col>
      <el-col :span="12">
        <ttable
          :table="moTestStandardParamTable"
          :uploadInfo="moTestStandardParamUploadInfo"
          :prelang="moTestStandardParamPrelang"
          :options="moTestStandardParamOptions"
          :ajaxFun="moTestStandardParamAjaxFun"
          :bottomOffset="200"
          :paramObj="paramObj"
          ref="moTestStandardParamTable"
        >
          <template #toolbar></template>
        </ttable>
      </el-col>
    </el-row>
    <!-- 弹窗, 新增 / 修改 -->
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>

<script>
import { delObj } from '@/api/quality/parts'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import {
  getManufacturingOrderStand,
  getOperationTestStandardParamQuality
} from '../../../api/plan/moteststandard'

export default {
  components: {
    ttable
  },
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    multiSelect: {
      type: Boolean,
      default: false
    }
  },

  data() {
    return {
      currentRow: [],
      innerVisible: false,
      ajaxFun: getManufacturingOrderStand,
      addOrUpdateVisible: false,
      isShowQuery: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'moNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '30',
            prop: 'customerOrderNo',
            label: '客户订单编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'moNo',
            label: '制造订单编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'standardName',
            label: '标准名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'standardNo',
            label: '标准编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      paramObj: { moTestStandardId: 0 },
      moTestStandardParamAjaxFun: getOperationTestStandardParamQuality,
      moTestStandardParamUploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      moTestStandardParamPrelang: 'operation',
      moTestStandardParamOptions: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'code', direction: 'desc' }
      },
      moTestStandardParamTable: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '30',
            prop: 'code',
            label: '参数编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'parameterItem',
            label: '参数项',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'referenceValue',
            label: '检测范围',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'paramType',
            label: '检测类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'aisle',
            label: '通道',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'position',
            label: '部位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      }
    }
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
          this.getJoinData()
        })
      }
    }
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.moTestStandardTable.getDataList()
    },
    getJoinData() {
      this.$refs.moTestStandardParamTable.getDataList()
    },
    saveSelectRow() {
      if (this.multiSelect) {
        this.$emit('handleSelectionChange', this.multipleSelection)
      } else {
        this.$emit('listenToPartsEvent', this.currentRow)
      }
      this.innerVisible = false
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    handleCurrentChange(val) {
      this.currentRow = val
      this.paramObj = { moTestStandardId: val.id }
      this.$nextTick(() => {
        this.getJoinData()
      })
    }
  }
}
</script>
